@@ -1,7 +1,7 @@
 /** @file
  * @brief parsing a user query string to build a Xapian::Query object
  */
-/* Copyright (C) 2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2021 Olly Betts
+/* Copyright (C) 2005-2023 Olly Betts
  * Copyright (C) 2010 Adam Sjøgren
  *
  * This program is free software; you can redistribute it and/or
@@ -73,7 +73,7 @@ class XAPIAN_VISIBILITY_DEFAULT Stopper
 
     /** Start reference counting this object.
      *
-     *  You can hand ownership of a dynamically allocated Stopper
+     *  You can transfer ownership of a dynamically allocated Stopper
      *  object to Xapian by calling release() and then passing the object to a
      *  Xapian method.  Xapian will arrange to delete the object once it is no
      *  longer required.
@@ -85,7 +85,7 @@ class XAPIAN_VISIBILITY_DEFAULT Stopper
 
     /** Start reference counting this object.
      *
-     *  You can hand ownership of a dynamically allocated Stopper
+     *  You can transfer ownership of a dynamically allocated Stopper
      *  object to Xapian by calling release() and then passing the object to a
      *  Xapian method.  Xapian will arrange to delete the object once it is no
      *  longer required.
@@ -223,7 +223,7 @@ class XAPIAN_VISIBILITY_DEFAULT RangeProcessor
 
     /** Start reference counting this object.
      *
-     *  You can hand ownership of a dynamically allocated RangeProcessor
+     *  You can transfer ownership of a dynamically allocated RangeProcessor
      *  object to Xapian by calling release() and then passing the object to a
      *  Xapian method.  Xapian will arrange to delete the object once it is no
      *  longer required.
@@ -235,7 +235,7 @@ class XAPIAN_VISIBILITY_DEFAULT RangeProcessor
 
     /** Start reference counting this object.
      *
-     *  You can hand ownership of a dynamically allocated RangeProcessor
+     *  You can transfer ownership of a dynamically allocated RangeProcessor
      *  object to Xapian by calling release() and then passing the object to a
      *  Xapian method.  Xapian will arrange to delete the object once it is no
      *  longer required.
@@ -751,7 +751,7 @@ class XAPIAN_VISIBILITY_DEFAULT FieldProcessor
 
     /** Start reference counting this object.
      *
-     *  You can hand ownership of a dynamically allocated FieldProcessor
+     *  You can transfer ownership of a dynamically allocated FieldProcessor
      *  object to Xapian by calling release() and then passing the object to a
      *  Xapian method.  Xapian will arrange to delete the object once it is no
      *  longer required.
@@ -763,7 +763,7 @@ class XAPIAN_VISIBILITY_DEFAULT FieldProcessor
 
     /** Start reference counting this object.
      *
-     *  You can hand ownership of a dynamically allocated FieldProcessor
+     *  You can transfer ownership of a dynamically allocated FieldProcessor
      *  object to Xapian by calling release() and then passing the object to a
      *  Xapian method.  Xapian will arrange to delete the object once it is no
      *  longer required.
@@ -870,20 +870,38 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
 	 */
 	FLAG_AUTO_MULTIWORD_SYNONYMS = 1024,
 
-	/** Enable generation of n-grams from CJK text.
+	/** Generate n-grams for scripts without explicit word breaks.
 	 *
-	 *  With this enabled, spans of CJK characters are split into unigrams
+	 *  Spans of characters in such scripts are split into unigrams
 	 *  and bigrams, with the unigrams carrying positional information.
-	 *  Non-CJK characters are split into words as normal.
+	 *  Text in other scripts is split into words as normal.
 	 *
-	 *  The corresponding option needs to have been used at index time.
+	 *  The TermGenerator::FLAG_NGRAMS flag needs to have been used at
+	 *  index time.
 	 *
-	 *  Flag added in Xapian 1.3.4 and 1.2.22.  This mode can be
-	 *  enabled in 1.2.8 and later by setting environment variable
-	 *  XAPIAN_CJK_NGRAM to a non-empty value (but doing so was deprecated
-	 *  in 1.4.11).
+	 *  This mode can also be enabled in 1.2.8 and later by setting
+	 *  environment variable XAPIAN_CJK_NGRAM to a non-empty value (but
+	 *  doing so was deprecated in 1.4.11).
+	 *
+	 *  In 1.4.x this feature was specific to CJK (Chinese, Japanese and
+	 *  Korean), but in 1.5.0 it's been extended to other languages.  To
+	 *  reflect this change the new and preferred name is FLAG_NGRAMS,
+	 *  which was added as an alias for forward compatibility in Xapian
+	 *  1.4.23.  Use FLAG_CJK_NGRAM instead if you aim to support Xapian
+	 *  &lt; 1.4.23.
+	 *
+	 *  @since Added in Xapian 1.4.23.
 	 */
-	FLAG_CJK_NGRAM = 2048,
+	FLAG_NGRAMS = 2048,
+
+	/** Generate n-grams for scripts without explicit word breaks.
+	 *
+	 *  Old name - use FLAG_NGRAMS instead unless you aim to support Xapian
+	 *  &lt; 1.4.23.
+	 *
+	 *  @since Added in Xapian 1.3.4 and 1.2.22.
+	 */
+	FLAG_CJK_NGRAM = FLAG_NGRAMS,
 
 	/** Accumulate unstem and stoplist results.
 	 *
@@ -1126,8 +1144,13 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  In 1.0.3 and earlier, subsequent calls to this method with the same
      *  value of @a field had no effect.
      *
-     *  @param field   The user visible field name
-     *  @param prefix  The term prefix to map this to
+     *  @param field   The user visible field name.  Currently this needs to
+     *		       consist of characters for which
+     *		       Xapian::Unicode::is_wordchar() is true (approximately
+     *		       alphanumerics plus connector punctuation such as `_`).
+     *		       Since 1.4.26 it can optionally end in a `:` for
+     *		       consistency with how range prefixes are specified.
+     *  @param prefix  The term prefix to map this to.
      */
     void add_prefix(const std::string& field, const std::string& prefix);
 
@@ -1177,7 +1200,13 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  In 1.0.3 and earlier, subsequent calls to this method with the same
      *  value of @a field had no effect.
      *
-     *  @param field   The user visible field name
+     *  @param field   The user visible field name, which may not be empty
+     *		       for a boolean filter.  Currently this needs to
+     *		       consist of characters for which
+     *		       Xapian::Unicode::is_wordchar() is true (approximately
+     *		       alphanumerics plus connector punctuation such as `_`).
+     *		       Since 1.4.26 it can optionally end in a `:` for
+     *		       consistency with how range prefixes are specified.
      *  @param prefix  The term prefix to map this to
      *  @param grouping	Controls how multiple filters are combined - filters
      *			with the same grouping value are combined with OP_OR,
@@ -1197,7 +1226,13 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  This is an older version of this method - use the version with
      *  the `grouping` parameter in preference to this one.
      *
-     *  @param field   The user visible field name
+     *  @param field   The user visible field name, which may not be empty
+     *		       for a boolean filter.  Currently this needs to
+     *		       consist of characters for which
+     *		       Xapian::Unicode::is_wordchar() is true (approximately
+     *		       alphanumerics plus connector punctuation such as `_`).
+     *		       Since 1.4.26 it can optionally end in a `:` for
+     *		       consistency with how range prefixes are specified.
      *  @param prefix  The term prefix to map this to
      *  @param exclusive Controls how multiple filters are combined.  If
      *			true then @a prefix is used as the `grouping` value,
