@@ -36,7 +36,7 @@
 #define XAPIAN_ENABLE_VISIBILITY
 
 /// The version of Xapian as a C string literal.
-#define XAPIAN_VERSION "1.4.26"
+#define XAPIAN_VERSION "1.4.27"
 
 /** The major component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 1
@@ -51,7 +51,7 @@
 /** The revision component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 14
  */
-#define XAPIAN_REVISION 26
+#define XAPIAN_REVISION 27
 
 /// Base (signed) type for Xapian::docid and related types.
 #define XAPIAN_DOCID_BASE_TYPE int
@@ -63,10 +63,10 @@
 #define XAPIAN_TERMPOS_BASE_TYPE int
 
 /// Type for returning total document length.
-#define XAPIAN_TOTALLENGTH_TYPE unsigned long
+#define XAPIAN_TOTALLENGTH_TYPE unsigned long long
 
 /// Underlying type for Xapian::rev.
-#define XAPIAN_REVISION_TYPE unsigned long
+#define XAPIAN_REVISION_TYPE unsigned long long
 
 /// XAPIAN_HAS_CHERT_BACKEND Defined if the chert backend is enabled.
 #define XAPIAN_HAS_CHERT_BACKEND 1
